==> zerochplus_0.5.10.tar.gz: zerochplus_0.5.10/test/mordor/sauron.pl <==
#============================================================================================================
#
#	ǗCGIx[XW[
#	sauron.pl
#	---------------------------------------------------------------------------
#	2003.10.12 start
#
#============================================================================================================
package	SAURON;

use strict;
use warnings;

require './module/thorin.pl';

#------------------------------------------------------------------------------------------------------------
#
#	W[RXgN^ - new
#	-------------------------------------------------------------------------------------
#	@FȂ
#	߂lFW[IuWFNg
#
#------------------------------------------------------------------------------------------------------------
sub new
{
	my $this = shift;
	my ($obj, @MnuStr, @MnuUrl);
	
	$obj = {
		'SYS'		=> undef,														# MELKORێ
		'FORM'		=> undef,														# SAMWISEێ
		'INN'		=> undef,														# THORINێ
		'MNUSTR'	=> \@MnuStr,													# @\Xg
		'MNUURL'	=> \@MnuUrl,													# @\XgURL
		'MNUNUM'	=> 0															# @\Xg
	};
	bless $obj, $this;
	
	return $obj;
}

#------------------------------------------------------------------------------------------------------------
#
#	IuWFNg - Create
#	-------------------------------------------------------------------------------------
#	@F$M : MELKORW[
#			$S : SAMWISEW[
#	߂lFTHORINW[
#
#------------------------------------------------------------------------------------------------------------
sub Create
{
	my $this = shift;
	my ($Sys, $Form) = @_;
	
	$this->{'SYS'}		= $Sys;
	$this->{'FORM'}		= $Form;
	$this->{'INN'}		= THORIN->new;
	$this->{'MNUNUM'}	= 0;
	
	return $this->{'INN'};
}

#------------------------------------------------------------------------------------------------------------
#
#	j[̐ݒ - SetMenu
#	-------------------------------------------------------------------------------------
#	@F$str : \
#			$url : WvURL
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub SetMenu
{
	my $this = shift;
	my ($str, $url) = @_;
	
	push @{$this->{'MNUSTR'}}, $str;
	push @{$this->{'MNUURL'}}, $url;
	
	$this->{'MNUNUM'} ++;
}

#------------------------------------------------------------------------------------------------------------
#
#	y[Wo - Print
#	-------------------------------------------------------------------------------------
#	@F$ttl : y[W^Cg
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub Print
{
	my $this = shift;
	my ($ttl, $mode) = @_;
	my ($Tad, $Tin, $TPlus);
	
	$Tad	= THORIN->new;
	$Tin	= $this->{'INN'};
	
	PrintHTML($Tad, $ttl);																# HTMLwb_o
	PrintCSS($Tad, $this->{'SYS'});														# CSSo
	PrintHead($Tad, $ttl, $mode);														# wb_o
	PrintList($Tad, $this->{'MNUNUM'}, $this->{'MNUSTR'}, $this->{'MNUURL'});			# @\Xgo
	PrintInner($Tad, $Tin, $ttl);														# @\eo
	PrintCommonInfo($Tad, $this->{'FORM'});
	PrintFoot($Tad, $this->{'FORM'}->Get('UserName'), $this->{'SYS'}->Get('VERSION'));	# tb^o
	
	$Tad->Flush(0, 0, '');																# ʏo
}

#------------------------------------------------------------------------------------------------------------
#
#	y[Wo(j[XgȂ) - PrintNoList
#	-------------------------------------------------------------------------------------
#	@F$ttl : y[W^Cg
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub PrintNoList
{
	my $this = shift;
	my ($ttl, $mode) = @_;
	my ($Tad, $Tin);
	
	$Tad = THORIN->new;
	$Tin = $this->{'INN'};
	
	PrintHTML($Tad, $ttl);															# HTMLwb_o
	PrintCSS($Tad, $this->{'SYS'}, $ttl);											# CSSo
	PrintHead($Tad, $ttl, $mode);													# wb_o
	PrintInner($Tad, $Tin, $ttl);													# @\eo
	PrintFoot($Tad, 'NONE', $this->{'SYS'}->Get('VERSION'));						# tb^o
	
	$Tad->Flush(0, 0, '');															# ʏo
}

#------------------------------------------------------------------------------------------------------------
#
#	HTMLwb_o - PrintHTML
#	-------------------------------------------
#	@F$T   : THORINW[
#			$ttl : y[W^Cg
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub PrintHTML
{
	my ($Page, $ttl) = @_;
	
	$Page->Print("Content-type: text/html\n\n");
	$Page->Print(<<HTML);
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html lang="ja">
<head>
 
 <title>낿˂vXǗ - [ $ttl ]</title>
 
HTML
	
}

#------------------------------------------------------------------------------------------------------------
#
#	X^CV[go - PrintCSS
#	-------------------------------------------
#	@F$Page   : THORINW[
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub PrintCSS
{
	my ($Page, $Sys, $ttl) = @_;
	my ($data);
	
	$data = $Sys->Get('DATA');
	
$Page->Print(<<HTML);
 <meta http-equiv=Content-Type content="text/html;charset=Shift_JIS">
 
 <meta http-equiv="Content-Script-Type" content="text/javascript">
 <meta http-equiv="Content-Style-Type" content="text/css">
 
 <meta name="robots" content="noindex,nofollow">
 
 <link rel="stylesheet" href=".$data/admin.css" type="text/css">
 <script language="javascript" src=".$data/admin.js"></script>
 
</head>
<!--nobanner-->
HTML
	
}

#------------------------------------------------------------------------------------------------------------
#
#	y[Wwb_o - PrintHead
#	-------------------------------------------
#	@F$Page   : THORINW[
#			$ttl : y[W^Cg
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub PrintHead
{
	my ($Page, $ttl, $mode) = @_;
	my ($common);
	
	$common = '<a href="javascript:DoSubmit';
	
$Page->Print(<<HTML);
<body>

<form name="ADMIN" action="./admin.cgi" method="POST">

<div class="MainMenu" align="right">
HTML
	
	# VXeǗj[
	if ($mode == 1) {
		
$Page->Print(<<HTML);
 <a href="javascript:DoSubmit('sys.top','DISP','NOTICE');">gbv</a> |
 <a href="javascript:DoSubmit('sys.bbs','DISP','LIST');">f</a> |
 <a href="javascript:DoSubmit('sys.user','DISP','LIST');">[U[</a> |
 <a href="javascript:DoSubmit('sys.cap','DISP','LIST');">Lbv</a> |
 <a href="javascript:DoSubmit('sys.setting','DISP','INFO');">VXeݒ</a> |
 <a href="javascript:DoSubmit('sys.edit','DISP','BANNER_PC');">eҏW</a> |
HTML
		
	}
	# fǗj[
	elsif ($mode == 2) {
		
$Page->Print(<<HTML);
 <a href="javascript:DoSubmit('bbs.thread','DISP','LIST');">Xbh</a> |
 <a href="javascript:DoSubmit('bbs.pool','DISP','LIST');">v[</a> |
 <a href="javascript:DoSubmit('bbs.kako','DISP','LIST');">ߋO</a> |
 <a href="javascript:DoSubmit('bbs.setting','DISP','SETINFO');">fݒ</a> |
 <a href="javascript:DoSubmit('bbs.edit','DISP','HEAD');">eҏW</a> |
 <a href="javascript:DoSubmit('bbs.user','DISP','LIST');">ǗO[v</a> |
 <a href="javascript:DoSubmit('bbs.cap','DISP','LIST');">LbvO[v</a> |
 <a href="javascript:DoSubmit('bbs.log','DISP','INFO');">O{</a> |
HTML
		
	}
	# XbhǗj[
	elsif ($mode == 3) {
		
$Page->Print(<<HTML);
 <a href="javascript:DoSubmit('thread.res','DISP','LIST');">Xꗗ</a> |
 <a href="javascript:DoSubmit('thread.del','DISP','LIST');">폜Xꗗ</a> |
HTML
		
	}
	
$Page->Print(<<HTML);
 <a href="javascript:DoSubmit('login','','');">OIt</a>
</div>
 
<div class="MainHead" align="right">0ch+ BBS System Manager</div>

<table cellspacing="0" width="100%" height="400">
 <tr>
HTML
	
}

#------------------------------------------------------------------------------------------------------------
#
#	@\Xgo - PrintList
#	-------------------------------------------
#	@F$Page   : THORINW[
#			$str : @\^Cgz
#			$url : @\URLz
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub PrintList
{
	my ($Page, $n, $str, $url) = @_;
	my ($i, $strURL, $strTXT);
	
$Page->Print(<<HTML);
  <td valign="top" class="Content">
  <table width="95%" cellspacing="0">
   <tr>
    <td class="FunctionList">
HTML
	
	for ($i = 0 ; $i < $n ; $i++) {
		$strURL = $$url[$i];
		$strTXT = $$str[$i];
		if ($strURL eq '') {
			$Page->Print("    <font color=\"gray\">$strTXT</font>\n");
			if ($strTXT ne '<hr>') {
				$Page->Print('    <br>'."\n");
			}
		}
		else {
			$Page->Print("    <a href=\"javascript:DoSubmit($$url[$i]);\">");
			$Page->Print("$$str[$i]</a><br>\n");
		}
	}
	
$Page->Print(<<HTML);
    </td>
   </tr>
  </table>
  </td>
HTML
	
}

#------------------------------------------------------------------------------------------------------------
#
#	@\eo - PrintInner
#	-------------------------------------------
#	@F$Page1 : THORINW[(MAIN)
#			$Page2 : THORINW[(e)
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub PrintInner
{
	my ($Page1, $Page2, $ttl) = @_;
	
$Page1->Print(<<HTML);
  <td width="80%" valign="top" class="Function">
  <div class="FuncTitle">$ttl</div>
HTML
	
	$Page1->Merge($Page2);
	
	$Page1->Print("  </td>\n");
	
}

#------------------------------------------------------------------------------------------------------------
#
#	ʏo - PrintCommonInfo
#	-------------------------------------------
#	@F$Page   : THORINW[
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub PrintCommonInfo
{
	my ($Page, $Form) = @_;
	my ($user, $pass);
	
	$user = $Form->Get('UserName');
	$pass = $Form->Get('PassWord');
	
$Page->Print(<<HTML);
  <!-- ȂƂɒnv(ry -->
   <input type="hidden" name="MODULE" value="">
   <input type="hidden" name="MODE" value="">
   <input type="hidden" name="MODE_SUB" value="">
   <input type="hidden" name="UserName" value="$user">
   <input type="hidden" name="PassWord" value="$pass">
  <!-- ȂƂɒnv(ry -->
HTML
	
}

#------------------------------------------------------------------------------------------------------------
#
#	tb^o - PrintFoot
#	-------------------------------------------
#	@F$Page   : THORINW[
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub PrintFoot
{
	my ($Page, $user, $ver) = @_;
	
$Page->Print(<<HTML);
 </tr>
</table>

<div class="MainFoot">
 Copyright 2001 - 2011 0ch+ BBS : Loggin User - <b>$user</b><br>
 Build Version:<b>$ver</b>
</div>

</form>

</body>
</html>
HTML
	
}

#------------------------------------------------------------------------------------------------------------
#
#	ʂ̏o
#	-------------------------------------------------------------------------------------
#	@param	$processName	
#	@param	$pLog	O
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub PrintComplete
{
	my $this = shift;
	my ($processName, $pLog) = @_;
	my ($Page, $text);
	
	$Page = $this->{'INN'};
	
$Page->Print(<<HTML);
  <table border="0" cellspacing="0" cellpadding="0" width="100%" align="center">
   <tr>
    <td>
    
    <div class="oExcuted">
     $processName𐳏Ɋ܂B
    </div>
   
    <div class="LogExport">O</div>
    <hr>
    <blockquote class="LogExport">
HTML
	
	# O̕\
	foreach $text (@$pLog) {
		$Page->Print("     $text<br>\n");
	}
	
$Page->Print(<<HTML);
    </blockquote>
    <hr>
    </td>
   </tr>
  </table>
HTML
	
}

#------------------------------------------------------------------------------------------------------------
#
#	G[̕\
#	-------------------------------------------------------------------------------------
#	@param	$pLog	Op
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub PrintError
{
	my $this = shift;
	my ($pLog) = @_;
	my ($Page, $ecode);
	
	$Page = $this->{'INN'};
	
	# G[R[h̒o
	$ecode = pop @$pLog;
	
$Page->Print(<<HTML);
  <table border="0" cellspacing="0" cellpadding="0" width="100%" align="center">
   <tr>
    <td>
    
    <div class="xExcuted">
HTML
	
	if ($ecode == 1000) {
		$Page->Print("     ERROR:$ecode - {@\\̏s錠܂B\n");
	}
	elsif ($ecode == 1001) {
		$Page->Print("     ERROR:$ecode - ͕K{ڂ󗓂ɂȂĂ܂B\n");
	}
	elsif ($ecode == 1002) {
		$Page->Print("     ERROR:$ecode - ݒ荀ڂɋKO̕gpĂ܂B\n");
	}
	elsif ($ecode == 2000) {
		$Page->Print("     ERROR:$ecode - ffBNg̍쐬Ɏs܂B<br>\n");
		$Page->Print("     p[~bVA܂͊ɓ̌f쐬ĂȂmFĂB\n");
	}
	elsif ($ecode == 2001) {
		$Page->Print("     ERROR:$ecode - SETTING.TXT̐Ɏs܂B\n");
	}
	elsif ($ecode == 2002) {
		$Page->Print("     ERROR:$ecode - f\\vf̐Ɏs܂B\n");
	}
	elsif ($ecode == 2003) {
		$Page->Print("     ERROR:$ecode - ߋO̐Ɏs܂B\n");
	}
	elsif ($ecode == 2004) {
		$Page->Print("     ERROR:$ecode - f̍XVɎs܂B\n");
	}
	else {
		$Page->Print("     ERROR:$ecode - sȃG[܂B\n");
	}
	
$Page->Print(<<HTML);
    </div>
    
HTML

	# G[OΏo͂
	if (@$pLog) {
		$Page->Print('<hr>');
		$Page->Print("    <blockquote>");
		foreach (@$pLog) {
			$Page->Print("    $_<br>\n");
		}
		$Page->Print("    </blockquote>");
		$Page->Print('<hr>');
	}
	
$Page->Print(<<HTML);
    </td>
   </tr>
  </table>
HTML
	
}

#============================================================================================================
#	W[I[
#============================================================================================================
1;

==> zerochplus_0.6.1.tar.gz: zerochplus_0.6.1/test/mordor/sauron.pl <==
#============================================================================================================
#
#	ǗCGIx[XW[
#	sauron.pl
#	---------------------------------------------------------------------------
#	2003.10.12 start
#
#============================================================================================================
package	SAURON;

use strict;
use warnings;

require './module/thorin.pl';

#------------------------------------------------------------------------------------------------------------
#
#	W[RXgN^ - new
#	-------------------------------------------------------------------------------------
#	@FȂ
#	߂lFW[IuWFNg
#
#------------------------------------------------------------------------------------------------------------
sub new
{
	my $this = shift;
	my ($obj, @MnuStr, @MnuUrl);
	
	$obj = {
		'SYS'		=> undef,														# MELKORێ
		'FORM'		=> undef,														# SAMWISEێ
		'INN'		=> undef,														# THORINێ
		'MNUSTR'	=> \@MnuStr,													# @\Xg
		'MNUURL'	=> \@MnuUrl,													# @\XgURL
		'MNUNUM'	=> 0															# @\Xg
	};
	bless $obj, $this;
	
	return $obj;
}

#------------------------------------------------------------------------------------------------------------
#
#	IuWFNg - Create
#	-------------------------------------------------------------------------------------
#	@F$M : MELKORW[
#			$S : SAMWISEW[
#	߂lFTHORINW[
#
#------------------------------------------------------------------------------------------------------------
sub Create
{
	my $this = shift;
	my ($Sys, $Form) = @_;
	
	$this->{'SYS'}		= $Sys;
	$this->{'FORM'}		= $Form;
	$this->{'INN'}		= THORIN->new;
	$this->{'MNUNUM'}	= 0;
	
	return $this->{'INN'};
}

#------------------------------------------------------------------------------------------------------------
#
#	j[̐ݒ - SetMenu
#	-------------------------------------------------------------------------------------
#	@F$str : \
#			$url : WvURL
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub SetMenu
{
	my $this = shift;
	my ($str, $url) = @_;
	
	push @{$this->{'MNUSTR'}}, $str;
	push @{$this->{'MNUURL'}}, $url;
	
	$this->{'MNUNUM'} ++;
}

#------------------------------------------------------------------------------------------------------------
#
#	y[Wo - Print
#	-------------------------------------------------------------------------------------
#	@F$ttl : y[W^Cg
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub Print
{
	my $this = shift;
	my ($ttl, $mode) = @_;
	my ($Tad, $Tin, $TPlus);
	
	$Tad	= THORIN->new;
	$Tin	= $this->{'INN'};
	
	PrintHTML($Tad, $ttl);																# HTMLwb_o
	PrintCSS($Tad, $this->{'SYS'});														# CSSo
	PrintHead($Tad, $ttl, $mode);														# wb_o
	PrintList($Tad, $this->{'MNUNUM'}, $this->{'MNUSTR'}, $this->{'MNUURL'});			# @\Xgo
	PrintInner($Tad, $Tin, $ttl);														# @\eo
	PrintCommonInfo($Tad, $this->{'FORM'});
	PrintFoot($Tad, $this->{'FORM'}->Get('UserName'), $this->{'SYS'}->Get('VERSION'));	# tb^o
	
	$Tad->Flush(0, 0, '');																# ʏo
}

#------------------------------------------------------------------------------------------------------------
#
#	y[Wo(j[XgȂ) - PrintNoList
#	-------------------------------------------------------------------------------------
#	@F$ttl : y[W^Cg
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub PrintNoList
{
	my $this = shift;
	my ($ttl, $mode) = @_;
	my ($Tad, $Tin);
	
	$Tad = THORIN->new;
	$Tin = $this->{'INN'};
	
	PrintHTML($Tad, $ttl);															# HTMLwb_o
	PrintCSS($Tad, $this->{'SYS'}, $ttl);											# CSSo
	PrintHead($Tad, $ttl, $mode);													# wb_o
	PrintInner($Tad, $Tin, $ttl);													# @\eo
	PrintFoot($Tad, 'NONE', $this->{'SYS'}->Get('VERSION'));						# tb^o
	
	$Tad->Flush(0, 0, '');															# ʏo
}

#------------------------------------------------------------------------------------------------------------
#
#	HTMLwb_o - PrintHTML
#	-------------------------------------------
#	@F$T   : THORINW[
#			$ttl : y[W^Cg
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub PrintHTML
{
	my ($Page, $ttl) = @_;
	
	$Page->Print("Content-type: text/html\n\n");
	$Page->Print(<<HTML);
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html lang="ja">
<head>
 
 <title>낿˂vXǗ - [ $ttl ]</title>
 
HTML
	
}

#------------------------------------------------------------------------------------------------------------
#
#	X^CV[go - PrintCSS
#	-------------------------------------------
#	@F$Page   : THORINW[
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub PrintCSS
{
	my ($Page, $Sys, $ttl) = @_;
	my ($data);
	
	$data = $Sys->Get('DATA');
	
$Page->Print(<<HTML);
 <meta http-equiv=Content-Type content="text/html;charset=Shift_JIS">
 
 <meta http-equiv="Content-Script-Type" content="text/javascript">
 <meta http-equiv="Content-Style-Type" content="text/css">
 
 <meta name="robots" content="noindex,nofollow">
 
 <link rel="stylesheet" href=".$data/admin.css" type="text/css">
 <script language="javascript" src=".$data/admin.js"></script>
 
</head>
<!--nobanner-->
HTML
	
}

#------------------------------------------------------------------------------------------------------------
#
#	y[Wwb_o - PrintHead
#	-------------------------------------------
#	@F$Page   : THORINW[
#			$ttl : y[W^Cg
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub PrintHead
{
	my ($Page, $ttl, $mode) = @_;
	my ($common);
	
	$common = '<a href="javascript:DoSubmit';
	
$Page->Print(<<HTML);
<body>

<form name="ADMIN" action="./admin.cgi" method="POST"@{[$mode ? ' onsubmit="return Submitted();"' : '']}>

<div class="MainMenu" align="right">
HTML
	
	# VXeǗj[
	if ($mode == 1) {
		
$Page->Print(<<HTML);
 <a href="javascript:DoSubmit('sys.top','DISP','NOTICE');">gbv</a> |
 <a href="javascript:DoSubmit('sys.bbs','DISP','LIST');">f</a> |
 <a href="javascript:DoSubmit('sys.user','DISP','LIST');">[U[</a> |
 <a href="javascript:DoSubmit('sys.cap','DISP','LIST');">Lbv</a> |
 <a href="javascript:DoSubmit('sys.capg','DISP','LIST');">ʃLbvO[v</a> |
 <a href="javascript:DoSubmit('sys.setting','DISP','INFO');">VXeݒ</a> |
 <a href="javascript:DoSubmit('sys.edit','DISP','BANNER_PC');">eҏW</a> |
HTML
		
	}
	# fǗj[
	elsif ($mode == 2) {
		
$Page->Print(<<HTML);
 <a href="javascript:DoSubmit('bbs.thread','DISP','LIST');">Xbh</a> |
 <a href="javascript:DoSubmit('bbs.pool','DISP','LIST');">v[</a> |
 <a href="javascript:DoSubmit('bbs.kako','DISP','LIST');">ߋO</a> |
 <a href="javascript:DoSubmit('bbs.setting','DISP','SETINFO');">fݒ</a> |
 <a href="javascript:DoSubmit('bbs.edit','DISP','HEAD');">eҏW</a> |
 <a href="javascript:DoSubmit('bbs.user','DISP','LIST');">ǗO[v</a> |
 <a href="javascript:DoSubmit('bbs.cap','DISP','LIST');">LbvO[v</a> |
 <a href="javascript:DoSubmit('bbs.log','DISP','INFO');">O{</a> |
HTML
		
	}
	# XbhǗj[
	elsif ($mode == 3) {
		
$Page->Print(<<HTML);
 <a href="javascript:DoSubmit('thread.res','DISP','LIST');">Xꗗ</a> |
 <a href="javascript:DoSubmit('thread.del','DISP','LIST');">폜Xꗗ</a> |
HTML
		
	}
	
$Page->Print(<<HTML);
 <a href="javascript:DoSubmit('login','','');">OIt</a>
</div>
 
<div class="MainHead" align="right">0ch+ BBS System Manager</div>

<table cellspacing="0" width="100%" height="400">
 <tr>
HTML
	
}

#------------------------------------------------------------------------------------------------------------
#
#	@\Xgo - PrintList
#	-------------------------------------------
#	@F$Page   : THORINW[
#			$str : @\^Cgz
#			$url : @\URLz
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub PrintList
{
	my ($Page, $n, $str, $url) = @_;
	my ($i, $strURL, $strTXT);
	
$Page->Print(<<HTML);
  <td valign="top" class="Content">
  <table width="95%" cellspacing="0">
   <tr>
    <td class="FunctionList">
HTML
	
	for ($i = 0 ; $i < $n ; $i++) {
		$strURL = $$url[$i];
		$strTXT = $$str[$i];
		if ($strURL eq '') {
			$Page->Print("    <font color=\"gray\">$strTXT</font>\n");
			if ($strTXT ne '<hr>') {
				$Page->Print('    <br>'."\n");
			}
		}
		else {
			$Page->Print("    <a href=\"javascript:DoSubmit($$url[$i]);\">");
			$Page->Print("$$str[$i]</a><br>\n");
		}
	}
	
$Page->Print(<<HTML);
    </td>
   </tr>
  </table>
  </td>
HTML
	
}

#------------------------------------------------------------------------------------------------------------
#
#	@\eo - PrintInner
#	-------------------------------------------
#	@F$Page1 : THORINW[(MAIN)
#			$Page2 : THORINW[(e)
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub PrintInner
{
	my ($Page1, $Page2, $ttl) = @_;
	
$Page1->Print(<<HTML);
  <td width="80%" valign="top" class="Function">
  <div class="FuncTitle">$ttl</div>
HTML
	
	$Page1->Merge($Page2);
	
	$Page1->Print("  </td>\n");
	
}

#------------------------------------------------------------------------------------------------------------
#
#	ʏo - PrintCommonInfo
#	-------------------------------------------
#	@F$Page   : THORINW[
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub PrintCommonInfo
{
	my ($Page, $Form) = @_;
	my ($user, $pass);
	
	$user = $Form->Get('UserName');
	$pass = $Form->Get('PassWord');
	
$Page->Print(<<HTML);
  <!-- ȂƂɒnv(ry -->
   <input type="hidden" name="MODULE" value="">
   <input type="hidden" name="MODE" value="">
   <input type="hidden" name="MODE_SUB" value="">
   <input type="hidden" name="UserName" value="$user">
   <input type="hidden" name="PassWord" value="$pass">
  <!-- ȂƂɒnv(ry -->
HTML
	
}

#------------------------------------------------------------------------------------------------------------
#
#	tb^o - PrintFoot
#	-------------------------------------------
#	@F$Page   : THORINW[
#	߂lFȂ
#
#------------------------------------------------------------------------------------------------------------
sub PrintFoot
{
	my ($Page, $user, $ver) = @_;
	
$Page->Print(<<HTML);
 </tr>
</table>

<div class="MainFoot">
 Copyright 2001 - 2011 0ch+ BBS : Loggin User - <b>$user</b><br>
 Build Version:<b>$ver</b>
</div>

</form>

</body>
</html>
HTML
	
}

#------------------------------------------------------------------------------------------------------------
#
#	ʂ̏o
#	-------------------------------------------------------------------------------------
#	@param	$processName	
#	@param	$pLog	O
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub PrintComplete
{
	my $this = shift;
	my ($processName, $pLog) = @_;
	my ($Page, $text);
	
	$Page = $this->{'INN'};
	
$Page->Print(<<HTML);
  <table border="0" cellspacing="0" cellpadding="0" width="100%" align="center">
   <tr>
    <td>
    
    <div class="oExcuted">
     $processName𐳏Ɋ܂B
    </div>
   
    <div class="LogExport">O</div>
    <hr>
    <blockquote class="LogExport">
HTML
	
	# O̕\
	foreach $text (@$pLog) {
		$Page->Print("     $text<br>\n");
	}
	
$Page->Print(<<HTML);
    </blockquote>
    <hr>
    </td>
   </tr>
  </table>
HTML
	
}

#------------------------------------------------------------------------------------------------------------
#
#	G[̕\
#	-------------------------------------------------------------------------------------
#	@param	$pLog	Op
#	@return	Ȃ
#
#------------------------------------------------------------------------------------------------------------
sub PrintError
{
	my $this = shift;
	my ($pLog) = @_;
	my ($Page, $ecode);
	
	$Page = $this->{'INN'};
	
	# G[R[h̒o
	$ecode = pop @$pLog;
	
$Page->Print(<<HTML);
  <table border="0" cellspacing="0" cellpadding="0" width="100%" align="center">
   <tr>
    <td>
    
    <div class="xExcuted">
HTML
	
	if ($ecode == 1000) {
		$Page->Print("     ERROR:$ecode - {@\\̏s錠܂B\n");
	}
	elsif ($ecode == 1001) {
		$Page->Print("     ERROR:$ecode - ͕K{ڂ󗓂ɂȂĂ܂B\n");
	}
	elsif ($ecode == 1002) {
		$Page->Print("     ERROR:$ecode - ݒ荀ڂɋKO̕gpĂ܂B\n");
	}
	elsif ($ecode == 2000) {
		$Page->Print("     ERROR:$ecode - ffBNg̍쐬Ɏs܂B<br>\n");
		$Page->Print("     p[~bVA܂͊ɓ̌f쐬ĂȂmFĂB\n");
	}
	elsif ($ecode == 2001) {
		$Page->Print("     ERROR:$ecode - SETTING.TXT̐Ɏs܂B\n");
	}
	elsif ($ecode == 2002) {
		$Page->Print("     ERROR:$ecode - f\\vf̐Ɏs܂B\n");
	}
	elsif ($ecode == 2003) {
		$Page->Print("     ERROR:$ecode - ߋO̐Ɏs܂B\n");
	}
	elsif ($ecode == 2004) {
		$Page->Print("     ERROR:$ecode - f̍XVɎs܂B\n");
	}
	else {
		$Page->Print("     ERROR:$ecode - sȃG[܂B\n");
	}
	
$Page->Print(<<HTML);
    </div>
    
HTML

	# G[OΏo͂
	if (@$pLog) {
		$Page->Print('<hr>');
		$Page->Print("    <blockquote>");
		foreach (@$pLog) {
			$Page->Print("    $_<br>\n");
		}
		$Page->Print("    </blockquote>");
		$Page->Print('<hr>');
	}
	
$Page->Print(<<HTML);
    </td>
   </tr>
  </table>
HTML
	
}

#============================================================================================================
#	W[I[
#============================================================================================================
1;
